Citations
---------

Papers for databases and software tools used in this work.

## Databases

### PDSP Ki DATABASE
1. The Multiplicity of Serotonin Receptors: Uselessly diverse molecules or an embarrasment of riches? BL Roth, WK Kroeze, S Patel and E Lopez: The Neuroscientist, 6:252-262, 2000
2. Science Netwatch, {28 January 2000; 287 (5453)}.

### Zinc
3. Irwin, Sterling, Mysinger, Bolstad and Coleman, J. Chem. Inf. Model. 2012 DOI: 10.1021/ci3001277. 
4. Irwin and Shoichet, J. Chem. Inf. Model. 2005;45(1):177-82

### ChEBI
5. Hastings, J., de Matos, P., Dekker, A., Ennis, M., Harsha, B., Kale, N., Muthukrishnan, V., Owen, G., Turner, S., Williams, M., and Steinbeck, C. (2013) The ChEBI reference database and ontology for biologically relevant chemistry: enhancements for 2013. Nucleic Acids Res.

### PubChem
6. Kim S, Thiessen PA, Bolton EE, Chen J, Fu G, Gindulyte A, Han L, He J, He S, Shoemaker BA, Wang J, Yu B, Zhang J, Bryant SH. PubChem Substance and Compound databases. Nucleic Acids Res. 2016 Jan 4; 44(D1):D1202-13. Epub 2015 Sep 22 doi: 10.1093/nar/gkv951

### DrugBank
7. Law V, Knox C, Djoumbou Y, Jewison T, Guo AC, Liu Y, Maciejewski A, Arndt D, Wilson M, Neveu V, Tang A, Gabriel G, Ly C, Adamjee S, Dame ZT, Han B, Zhou Y, Wishart DS. DrugBank 4.0: shedding new light on drug metabolism. Nucleic Acids Res. 2014 Jan 1;42(1):D1091-7.

### KEGG
8. Kanehisa, M., Sato, Y., Kawashima, M., Furumichi, M., and Tanabe, M.; KEGG as a reference resource for gene and protein annotation. Nucleic Acids Res. 44, D457-D462 (2016).
9. Kanehisa, M. and Goto, S.; KEGG: Kyoto Encyclopedia of Genes and Genomes. Nucleic Acids Res. 28, 27-30 (2000).

### BiGG
10. Zachary A. King, Justin Lu, Andreas Dräger, Philip Miller, Stephen Federowicz, Joshua A. Lerman, Ali Ebrahim, Bernhard O. Palsson, and Nathan E. Lewis BiGG Models: A platform for integrating, standardizing and sharing genome-scale models Nucl. Acids Res. (04 January 2016) 44 (D1): D515-D522 first published online October 17, 2015 doi:10.1093/nar/gkv1049

### BindingDB
11. Tiqing Liu, Yuhmei Lin, Xin Wen, Robert N. Jorissen, and Michael K. Gilson BindingDB: a web-accessible database of experimentally determined protein–ligand binding affinities Nucleic Acids Res. 2007 Jan; 35(Database issue): D198–D201. Published online 2006 Dec 1. doi:  10.1093/nar/gkl999

## Solubility
12. Delaney, J. S. (2004). ESOL: Estimating aqueous solubility directly from molecular structure. Journal of Chemical Information and Computer Sciences, 44(3), 1000–1005. http://doi.org/10.1021/ci034243x

## Software Tools

## COBRApy
13. Ebrahim A, Lerman JA, Palsson BO, Hyduke DR (2013) COBRApy: COnstraints-Based Reconstruction and Analysis for Python. BMC Syst Biol 7: 74. Available: http://www.biomedcentral.com/1752-0509/7/74.

## Cameo
14. Computer-aided metabolic engineering and optimization; https://cameo.bio

### OpenBabel
15. Noel M O'Boyle, Michael Banck, Craig A James, Chris Morley, Tim Vandermeersch and Geoffrey R Hutchison Open Babel: An open chemical toolbox Journal of Cheminformatics 20113:33 DOI:10.1186/1758-2946-3-33

### RDKit
14. RDKit: Open-source cheminformatics; http://www.rdkit.org

